%{

This m-file belongs to the article 'Conversion of a CO-CO2 co-feed with a
porous tubular copper catalyst at low potential'
Authors: Anne Sustronk (1,2) , Nieck E. Benes (1) , Guido Mul (2)
(1) Films in Fluids, Department of Science and Technology, University of 
Twente
(2) Photocatalytic Synthesis Group, Department of Science and Technology, 
University of Twente

The file is used to calculate the electrical potential and overpotenial
for CO2 conversion and hydrogen evolution. See also figure S5

Version date m-file: November 2021

%}

clear all, close all, clc

F = 96485;              % Faraday Constant [C mol-1]
n = 2;                  % Amount of electrons involved in CO2 conversion or HER
R = 8.314;              % Gas constant [J mol-1 K-1]
T = 298;                % Temperature [K]
pH = 8.3;               % pH of catholyte

Pcell = 1.2;            % Pressure in reactor divided by standard pressure
cH = 10.^-pH;           % Concentration protons [-]
Ewe = -1.1;             % Working electrode potential vs Ag/AgCl

% Calling function to calculate overpotential for CO2 conversion and HER
[xCO,eta_AgAgCl_CO2conv] = CO2conv(n, F, R, T,Pcell, cH, Ewe);
[eta_AgAgCl_HER] = HER(n, F, R, T, Pcell, cH, Ewe);

% Creating a vector of the HER overpotential data
eta_AgAgCl_HER = eta_AgAgCl_HER*ones(1,length(xCO));

%% plot data
figure(1), box on

% CO2 conversion
plot(xCO,eta_AgAgCl_CO2conv.*1000)
ylabel('E_{WE} - E CO_2 conversion (mV)')
xlabel('Vol% CO in feed')

% HER
yyaxis right
plot(xCO,eta_AgAgCl_HER.*1000)
ylabel('E_{WE} - E HER (mV)')

%% CO2 conversion

function [xCO,eta_AgAgCl_CO2R] = CO2conv(n, F, R, T, Pcell,cH, Ewe)
% CO2 + 2H+ + 2e- -> CO + H2O

% Gibbs-free energies of formation (from Atkins' Physical Chemistry)
dGfCO2 = -394.36;                   % [kJ mol-1]
dGfCO = -137.17;                    % [kJ mol-1]
dGfH = 0;                           % [kJ mol-1]
dGfH2O = -237.13;                   % [kJ mol-1]

% Some other required constants
aH2O = 1;                           % Activity of water [-]
xCO = linspace(0,30,100)./100;      % Vol% CO in the feed
pCO = xCO*Pcell;                    % Partial CO pressure [-]
pCO2 = 0.5*Pcell;                   % Partial CO2 pressure [-]

% Calculation of Gibbs-free energy of reaction [kJ mol-1]
dGr = dGfCO + dGfH2O - (dGfCO2 + 2*dGfH); 

% Calculation of the equilibrium potential [V vs SHE]
EThermo = dGr/(-n*F/1000);

% Correction of the equillibrium potential for CO presence (amongst others)
% [V vs SHE]
E = EThermo - ((R*T)/(n*F)).*log((pCO.*aH2O)./(pCO2*cH^2));

% Converting to V vs Ag/AgCl considering a 3M NaCl Ag/AgCl reference electrode
E_AgAgCl = E - 0.197;               

% Overpotential [V]
eta_AgAgCl_CO2R = Ewe-E_AgAgCl;
end

%% HER

function [eta_AgAgCl_HER] = HER(n, F, R, T, Pcell,cH,Ewe)
% 2H+ + 2e- -> H2

% Gibbs-free energies of formation (from Atkins' Physical Chemistry)
dGfH = 0;                          % [kJ mol-1]
dGfH2 = 0;                         % [kJ mol-1]

% Calculation of Gibbs-free energy of reaction [kJ mol-1]
dGr = dGfH2 - (2*dGfH);

% Calculation of the equilibrium potential [V vs SHE]
EThermo = dGr/(-n*F/1000);

% Correction of the equillibrium potential for H+ and H2 presence [V vs SHE]
E = EThermo - ((R*T)/(n*F)).*log((Pcell/1000)./(cH^2));      

% Converting to V vs Ag/AgCl considering a 3M NaCl Ag/AgCl reference electrode
E_AgAgCl = E - 0.197;              

% Overpotential [V]
eta_AgAgCl_HER = Ewe-E_AgAgCl;

end