%{

This m-file belongs to the article 'Conversion of a CO-CO2 co-feed with a
porous tubular copper catalyst at low potential'
Authors: Anne Sustronk (1,2) , Nieck E. Benes (1) , Guido Mul (2)
(1) Films in Fluids, Department of Science and Technology, University of 
Twente
(2) Photocatalytic Synthesis Group, Department of Science and Technology, 
University of Twente

The file is used to perform f-test analysis on the CO-CO2 co-feed data of
Figure 3D in the article

Tests of residuals are based on info from N.R. Draper and H. Smith, 
Applied regression analysis (3rd edition)

Version date m-file: November 2021

%}

clear all, clc, close all

%% Data

disp('All data lumped together for CO concentration effect on CO2 conversion rate')
pCO = [2.5 5 7.5 10 15 20 25 27.5 30];
CO2conversionRate = [11.615 10.664 9.949 10.091 8.809 7.112 8.483 8.080 8.100];

%% Calculate error sum of squares

[ESS,YfitOutputv2] = SSE_lin(pCO,CO2conversionRate);

% Calculate residuals
EpsilonR = CO2conversionRate - YfitOutputv2(:,1)';
EpsilonF = CO2conversionRate - YfitOutputv2(:,2)';

%% Determine F-value

% Calculate degrees of freedom
dfR = length(pCO)-1;
dfF = length(pCO)-2;

F_CO = ((ESS(1)-ESS(2))/(dfR-dfF))/(ESS(2)/dfF)

% Calculate critical F-value
F_critical = finv(0.99,1,dfF)

%% Plot actual data

figure(1), clf(1), hold on
title('Actual data')
plot(pCO, CO2conversionRate, '*k')
xlabel('pCO (vol%)')
ylabel('CO_{2} conversion rate (nmol cm^{-2} s^{-1})')
hold off

%% Plot results for reduced model

% Plot residuals vs Xi
figure(20), clf(20), subplot(2,2,1), hold on
title('Residuals for  y_{i} = \beta_{0}')
plot(pCO, EpsilonR, '*k')
plot(linspace(0,pCO(end)),zeros(length(linspace(0,pCO(end)))),'--k')
xlabel('pCO (vol%)')
ylabel('\epsilon')
set(gcf,'units','centimeters','position',[1 9 16*(4/3) 16])
box on
hold off

% Check if residuals follow normal distribution
figure(20), subplot(2,2,2)
normplot(EpsilonR)
box on

% Plot residuals agains time order of the data
t = [5 3 9 4 7 2 6 8 1];
figure(20), subplot(2,2,3), hold on
title('Residuals versus time order')
plot(t,EpsilonR,'*k')
plot(linspace(0,9,9),zeros(9),'--k')
xlabel('Order of exp')
ylabel('Y_{i}-Y_{i,estim}')
box on
hold off

% Plot residuals agains the estimated value
figure(20), subplot(2,2,4), hold on
title('Residuals versus estimated value')
plot(YfitOutputv2(:,1)',EpsilonF,'*k')
plot(YfitOutputv2(:,1)',zeros(9),'--k')
xlabel('Y_{i,estim}')
ylabel('Y_{i}-Y_{i,estim}')
box on
hold off

%% Plot results for full model

% Plot residuals vs Xi for full model
figure(30), clf(30), subplot(2,2,1), hold on
title('Residuals for y = \beta_{0}+\beta_{1}x')
plot(pCO, EpsilonF, '*k')
plot(linspace(0,pCO(end)),zeros(length(linspace(0,pCO(end)))),'--k')
xlabel('pCO (vol%)')
ylabel('\epsilon')
set(gcf,'units','centimeters','position',[25 9 16*(4/3) 16])
hold off

% Check if residuals follow normal distribution
figure(30), subplot(2,2,2)
normplot(EpsilonF)

% Plot residuals agains time order of the data
t = [5 3 9 4 7 2 6 8 1];
figure(30), subplot(2,2,3), hold on
title('Residuals versus time order')
plot(t,EpsilonF,'*k')
plot(linspace(0,9,9),zeros(9),'--k')
xlabel('Order of exp')
ylabel('Y_{i}-Y_{i,estim}')
hold off

% Plot residuals agains the estimated value
figure(30), subplot(2,2,4), hold on
title('Residuals versus estimated value')
plot(YfitOutputv2(:,2)',EpsilonF,'*k')
plot(YfitOutputv2(:,2)',zeros(9),'--k')
xlabel('Y_{i,estim}')
ylabel('Y_{i}-Y_{i,estim}')
hold off