%{

This m-file belongs to the article 'Conversion of a CO-CO2 co-feed with a
porous tubular copper catalyst at low potential'
Authors: Anne Sustronk (1,2) , Nieck E. Benes (1) , Guido Mul (2)
(1) Films in Fluids, Department of Science and Technology, University of 
Twente
(2) Photocatalytic Synthesis Group, Department of Science and Technology, 
University of Twente

The file is used to perform f-test analysis on the CO-CO2 co-feed data of
Figure S3 in the article

Tests of residuals are based on info from N.R. Draper and H. Smith, 
Applied regression analysis (3rd edition)

Version date m-file: November 2021

%}

clear all, clc, close all

%% Data

disp('All data lumped together for CO concentration effect on HER')
pCO = [2.5 5 7.5 10 15 20 25 27.5 30];
H2Production = [7.570 6.262 7.421 5.694 6.373 6.667 5.269 5.969 5.159];

%% Calculate error sum of squares

% Calculate error sum of squares
[ESS,YfitOutputH2] = SSE_lin(pCO,H2Production);

% Plot residuals for least squares fit
EpsilonR = H2Production - YfitOutputH2(:,1)';
EpsilonF = H2Production - YfitOutputH2(:,2)';

%% Determine F-value

% Calculate degrees of freedom
dfR = length(pCO)-1;
dfF = length(pCO)-2;

F_CO = ((ESS(1)-ESS(2))/(dfR-dfF))/(ESS(2)/dfF)

% Calculate critical F-value
F_critical = finv(0.99,1,dfF)

%% Plot actual data
figure(1), clf(1), hold on
title('Actual data')
plot(pCO, H2Production, '*k')
xlabel('pCO (vol%)')
ylabel('H_{2} production rate (nmol cm^{-2} s^{-1})')
hold off


%% Plot results for reduced model
figure(20), clf(20), subplot(2,2,1), hold on
title('Residuals for y_{i} = \beta_{0}')
plot(pCO, EpsilonR, '*k')
plot(linspace(0,pCO(end)),zeros(length(linspace(0,pCO(end)))),'--k')
xlabel('pCO (vol%)')
ylabel('\epsilon')
set(gcf,'units','centimeters','position',[1 9 16*(4/3) 16])
box on
hold off

% Check if residuals follow normal distribution
figure(20), subplot(2,2,2)
normplot(EpsilonR)
box on

% Plot residuals agains time order of the data
t = [2 6 1 7 4 3 8 5 9];
figure(20), subplot(2,2,3), hold on
title('Residuals versus time order')
plot(t,EpsilonR,'*k')
plot(linspace(0,9,9),zeros(9),'--k')
xlabel('Order of exp')
ylabel('Y_{i}-Y_{i,estim}')
box on
hold off

% Plot residuals agains the estimated value
figure(20), subplot(2,2,4), hold on
title('Residuals versus estimated value')
plot(YfitOutputH2(:,1)',EpsilonF,'*k')
plot(YfitOutputH2(:,1)',zeros(9),'--k')
xlabel('Y_{i,estim}')
ylabel('Y_{i}-Y_{i,estim}')
box on
hold off


%% Plot results for full model
figure(30), clf(30), subplot(2,2,1), hold on
title('Residuals for y = \beta_{0}+\beta_{1}x')
plot(pCO, EpsilonF, '*k')
plot(linspace(0,pCO(end)),zeros(length(linspace(0,pCO(end)))),'--k')
xlabel('pCO (vol%)')
ylabel('\epsilon')
set(gcf,'units','centimeters','position',[25 9 16*(4/3) 16])
hold off

% Check if residuals follow normal distribution
figure(30), subplot(2,2,2)
normplot(EpsilonF)

% Plot residuals agains time order of the data
t = [2 6 1 7 4 3 8 5 9];
figure(30), subplot(2,2,3), hold on
title('Residuals versus time order')
plot(t,EpsilonF,'*k')
plot(linspace(0,9,9),zeros(9),'--k')
xlabel('Order of exp')
ylabel('Y_{i}-Y_{i,estim}')
hold off

% Plot residuals agains the estimated value
figure(30), subplot(2,2,4), hold on
title('Residuals versus estimated value')
plot(YfitOutputH2(:,2)',EpsilonF,'*k')
plot(YfitOutputH2(:,2)',zeros(9),'--k')
xlabel('Y_{i,estim}')
ylabel('Y_{i}-Y_{i,estim}')
hold off

